summaryrefslogtreecommitdiffstatshomepage
path: root/src
diff options
context:
space:
mode:
author Brian Troha <briantro@users.noreply.github.com>2012-07-29 20:03:32 +0000
committer Brian Troha <briantro@users.noreply.github.com>2012-07-29 20:03:32 +0000
commitb43a647b92c9f373b8ff7c10ea01dd35c9a5a723 (patch)
tree698edc6afbe31af23be920f9e8804e6fcf9c5098 /src
parent58f81a09217d290c3a26b0fe7662db881801ad94 (diff)
msm5205.c: Preserve the documentation differences between MSM6585 & MSM5205 now that support has been added to the msm5205.c driver.
Diffstat (limited to 'src')
-rw-r--r--src/emu/sound/msm5205.c46
1 files changed, 33 insertions, 13 deletions
diff --git a/src/emu/sound/msm5205.c b/src/emu/sound/msm5205.c
index 6857bb97dff..6ff6ffef440 100644
--- a/src/emu/sound/msm5205.c
+++ b/src/emu/sound/msm5205.c
@@ -11,25 +11,45 @@
* for the current sample rate
*
* 01/06/99
* separate MSM5205 emulator form adpcm.c and some fix
*/
#include "emu.h"
#include "msm5205.h"
/*
- *
- * MSM 5205 ADPCM chip:
- *
- * Data is streamed from a CPU by means of a clock generated on the chip.
- *
- * A reset signal is set high or low to determine whether playback (and interrupts) are occuring
- *
- *
- * TODO:
- * - convert to modern
- * - lowpass filter for MSM6585
- *
+
+ MSM 5205 ADPCM chip:
+
+ Data is streamed from a CPU by means of a clock generated on the chip.
+
+ A reset signal is set high or low to determine whether playback (and interrupts) are occuring.
+
+ MSM6585: is an upgraded MSM5205 voice synth IC.
+ Improvements:
+ More precise internal DA converter
+ Built in low-pass filter
+ Expanded sampling frequency
+
+ Differences between MSM6585 & MSM5205:
+
+ MSM6586 MSM5205
+ Master clock frequency 640kHz 384kHz
+ Sampling frequency 4k/8k/16k/32kHz 4k/6k/8kHz
+ ADPCM bit length 4-bit 3-bit/4-bit
+ DA converter 12-bit 10-bit
+ Low-pass filter -40dB/oct N/A
+ Overflow prevent circuit Included N/A
+
+ Timer callback at VCLK low edge on MSM5205 (at rising edge on MSM6585)
+
+ TODO:
+ - convert to modern
+ - lowpass filter for MSM6585
+
*/
typedef struct _msm5205_state msm5205_state;
@@ -11,25 +11,45 @@
*
* 01/06/99
- * separate MSM5205 emulator form adpcm.c and some fix
+ * separate MSM5205 emulator form adpcm.c and some fix
+ *
+ * 07/29/12
+ * added basic support for the MSM6585
*/
#include "emu.h"